pub struct ColorSyncCMM { /* private fields */ }Available on crate feature
ColorSyncCMM only.Expand description
Implementations
Sourceimpl ColorSyncCMM
impl ColorSyncCMM
pub unsafe fn new(cmm_bundle: &CFBundle) -> Option<CFRetained<ColorSyncCMM>>
pub unsafe fn bundle(&self) -> Option<CFRetained<CFBundle>>
pub unsafe fn localized_name(&self) -> Option<CFRetained<CFString>>
pub unsafe fn cmm_identifier(&self) -> Option<CFRetained<CFString>>
Methods from Deref<Target = CFType>
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: ConcreteType,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: ConcreteType,
Attempt to downcast the type to that of type T.
This is the reference-variant. Use CFRetained::downcast if you
want to convert a retained type. See also ConcreteType for more
details on which types support being converted to.
Sourcepub fn retain_count(&self) -> usize
pub fn retain_count(&self) -> usize
Get the reference count of the object.
This function may be useful for debugging. You normally do not use this function otherwise.
Beware that some things (like CFNumbers, small CFStrings etc.) may
not have a normal retain count for optimization purposes, and can
return usize::MAX in that case.