pub struct ColorSyncProfile { /* private fields */ }ColorSyncProfile only.Expand description
Implementations
Sourceimpl ColorSyncProfile
impl ColorSyncProfile
Sourcepub unsafe fn new(
data: &CFData,
error: *mut *mut CFError,
) -> Option<CFRetained<ColorSyncProfile>>
pub unsafe fn new( data: &CFData, error: *mut *mut CFError, ) -> Option<CFRetained<ColorSyncProfile>>
Safety
error must be a valid pointer or null.
Sourcepub unsafe fn with_url(
url: &CFURL,
error: *mut *mut CFError,
) -> Option<CFRetained<ColorSyncProfile>>
pub unsafe fn with_url( url: &CFURL, error: *mut *mut CFError, ) -> Option<CFRetained<ColorSyncProfile>>
Safety
error must be a valid pointer or null.
pub unsafe fn with_name(name: &CFString) -> Option<CFRetained<ColorSyncProfile>>
pub unsafe fn with_display_id( display_id: u32, ) -> Option<CFRetained<ColorSyncProfile>>
Sourcepub unsafe fn new_device_profile(
device_class: &CFString,
device_id: &CFUUID,
profile_id: &CFType,
) -> Option<CFRetained<ColorSyncProfile>>
pub unsafe fn new_device_profile( device_class: &CFString, device_id: &CFUUID, profile_id: &CFType, ) -> Option<CFRetained<ColorSyncProfile>>
Safety
profile_id should be of the correct type.
Sourceimpl ColorSyncProfile
impl ColorSyncProfile
Sourcepub unsafe fn new_link(
profile_info: &CFArray,
options: Option<&CFDictionary>,
) -> Option<CFRetained<ColorSyncProfile>>
pub unsafe fn new_link( profile_info: &CFArray, options: Option<&CFDictionary>, ) -> Option<CFRetained<ColorSyncProfile>>
Safety
profile_infogeneric must be of the correct type.optionsgenerics must be of the correct type.
Sourcepub unsafe fn verify(
&self,
errors: *mut *mut CFError,
warnings: *mut *mut CFError,
) -> bool
pub unsafe fn verify( &self, errors: *mut *mut CFError, warnings: *mut *mut CFError, ) -> bool
Safety
errorsmust be a valid pointer or null.warningsmust be a valid pointer or null.
pub unsafe fn is_wide_gamut(&self) -> bool
pub unsafe fn is_matrix_based(&self) -> bool
pub unsafe fn is_pq_based(&self) -> bool
pub unsafe fn is_hlg_based(&self) -> bool
Sourcepub unsafe fn estimate_gamma_with_display_id(
display_id: i32,
error: *mut *mut CFError,
) -> c_float
pub unsafe fn estimate_gamma_with_display_id( display_id: i32, error: *mut *mut CFError, ) -> c_float
Safety
error must be a valid pointer or null.
Sourcepub unsafe fn estimate_gamma(&self, error: *mut *mut CFError) -> c_float
pub unsafe fn estimate_gamma(&self, error: *mut *mut CFError) -> c_float
Safety
error must be a valid pointer or null.
Sourcepub unsafe fn display_transfer_formula_from_vcgt(
&self,
red_min: NonNull<c_float>,
red_max: NonNull<c_float>,
red_gamma: NonNull<c_float>,
green_min: NonNull<c_float>,
green_max: NonNull<c_float>,
green_gamma: NonNull<c_float>,
blue_min: NonNull<c_float>,
blue_max: NonNull<c_float>,
blue_gamma: NonNull<c_float>,
) -> bool
pub unsafe fn display_transfer_formula_from_vcgt( &self, red_min: NonNull<c_float>, red_max: NonNull<c_float>, red_gamma: NonNull<c_float>, green_min: NonNull<c_float>, green_max: NonNull<c_float>, green_gamma: NonNull<c_float>, blue_min: NonNull<c_float>, blue_max: NonNull<c_float>, blue_gamma: NonNull<c_float>, ) -> bool
Safety
red_minmust be a valid pointer.red_maxmust be a valid pointer.red_gammamust be a valid pointer.green_minmust be a valid pointer.green_maxmust be a valid pointer.green_gammamust be a valid pointer.blue_minmust be a valid pointer.blue_maxmust be a valid pointer.blue_gammamust be a valid pointer.
Sourcepub unsafe fn display_transfer_tables_from_vcgt(
&self,
n_samples_per_channel: NonNull<usize>,
) -> Option<CFRetained<CFData>>
pub unsafe fn display_transfer_tables_from_vcgt( &self, n_samples_per_channel: NonNull<usize>, ) -> Option<CFRetained<CFData>>
Safety
n_samples_per_channel must be a valid pointer.
Sourceimpl ColorSyncProfile
impl ColorSyncProfile
pub unsafe fn md_5(&self) -> ColorSyncMD5
Sourcepub unsafe fn data(&self, error: *mut *mut CFError) -> CFRetained<CFData>
pub unsafe fn data(&self, error: *mut *mut CFError) -> CFRetained<CFData>
Safety
error must be a valid pointer or null.
Sourcepub unsafe fn url(&self, error: *mut *mut CFError) -> CFRetained<CFURL>
pub unsafe fn url(&self, error: *mut *mut CFError) -> CFRetained<CFURL>
Safety
error must be a valid pointer or null.
pub unsafe fn header(&self) -> CFRetained<CFData>
Sourceimpl ColorSyncProfile
impl ColorSyncProfile
pub unsafe fn description_string(&self) -> Option<CFRetained<CFString>>
pub unsafe fn tag_signatures(&self) -> Option<CFRetained<CFArray>>
pub unsafe fn contains_tag(&self, signature: &CFString) -> bool
pub unsafe fn tag(&self, signature: &CFString) -> Option<CFRetained<CFData>>
Methods from Deref<Target = CFType>
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: ConcreteType,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: ConcreteType,
Attempt to downcast the type to that of type T.
This is the reference-variant. Use CFRetained::downcast if you
want to convert a retained type. See also ConcreteType for more
details on which types support being converted to.
Sourcepub fn retain_count(&self) -> usize
pub fn retain_count(&self) -> usize
Get the reference count of the object.
This function may be useful for debugging. You normally do not use this function otherwise.
Beware that some things (like CFNumbers, small CFStrings etc.) may
not have a normal retain count for optimization purposes, and can
return usize::MAX in that case.